@@ -12,52 +12,52 @@
     <message>
         <location filename="../src/about.ui" line="82"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="89"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="133"/>
         <source>tab0</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="178"/>
         <source>label_4</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="191"/>
         <source>label_5</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="204"/>
         <source>label_6</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="230"/>
         <source>tab1</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="257"/>
         <source>TextLabel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="316"/>
         <source>pushButton_3</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="335"/>
         <source>pushButton</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="38"/>
@@ -77,12 +77,12 @@
     <message>
         <location filename="../src/about.cpp" line="54"/>
         <source>Patrice Coni</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="56"/>
         <source>Copyright © 2022 - </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="62"/>
@@ -114,117 +114,149 @@ The application will be closed.</source>
 La sol·licitud estarà tancada.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
         <source>Reset</source>
-        <translation type="unfinished">Reinicialitzar</translation>
+        <translation>Reinicialitzar</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
         <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
-        <translation>No s&apos;ha trobat la carpeta que conté els plugins. Voleu configurar la carpeta manualment?</translation>
+        <translation type="vanished">No s&apos;ha trobat la carpeta que conté els plugins. Voleu configurar la carpeta manualment?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="120"/>
         <source>Select directory</source>
-        <translation type="unfinished">Seleccionar directori</translation>
+        <translation type="obsolete">Seleccionar directori</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
+        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
+        <translation>No s&apos;ha trobat la carpeta que conté els complements. Voleu definir la carpeta manualment?</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="125"/>
+        <source>Select Plugin Folder</source>
+        <translation>Selecciona el directori</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="134"/>
+        <source>No Plugins Found</source>
+        <translation>No s&apos;han trobat complements</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="135"/>
+        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
+        <translation>El directori no conté cap fitxer de complement. Trieu una carpeta de complements vàlida.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="323"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
+        <location filename="../src/mainwindow.cpp" line="323"/>
         <source>No plugins found.</source>
         <translation>No s&apos;han trobat connectors.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="315"/>
-        <location filename="../src/mainwindow.cpp" line="766"/>
+        <location filename="../src/mainwindow.cpp" line="329"/>
+        <location filename="../src/mainwindow.cpp" line="806"/>
         <source>done.</source>
         <translation>fet.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="316"/>
-        <location filename="../src/mainwindow.cpp" line="767"/>
+        <location filename="../src/mainwindow.cpp" line="330"/>
+        <location filename="../src/mainwindow.cpp" line="807"/>
         <source>Used plugin: </source>
         <translation>Plugin utilitzat: </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error while loading plugin.</source>
         <translation>Error en carregar el plugin.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="407"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
         <source>An error was detected when starting the application.
 The application will be closed.</source>
         <translation>S&apos;ha detectat un error en iniciar l&apos;aplicació.
 La aplicació licitud estarà tancada.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
-        <location filename="../src/mainwindow.cpp" line="833"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>No connection to the internet.</source>
         <translation>Sense connexió a internet.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>Please check your internet connection.</source>
         <translation>Comproveu la vostra connexió a Internet.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="756"/>
+        <location filename="../src/mainwindow.cpp" line="796"/>
         <source>&amp;Provider</source>
         <translation>&amp;Proveïdor</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="794"/>
+        <location filename="../src/mainwindow.cpp" line="834"/>
         <source>&amp;About this picture and license</source>
         <translation>&amp;Sobre aquesta imatge i llicència</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="798"/>
+        <location filename="../src/mainwindow.cpp" line="838"/>
         <source>&amp;About this picture and copyright</source>
         <translation>&amp;Sobre aquesta imatge i els drets d&apos;autor</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="805"/>
+        <location filename="../src/mainwindow.cpp" line="845"/>
         <source>&amp;Download past pictures</source>
         <translation>&amp;Descarregar imatges anteriors</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="809"/>
+        <location filename="../src/mainwindow.cpp" line="849"/>
         <source>&amp;Load stored picture</source>
         <translation>&amp;Carrega la imatge emmagatzemada</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="812"/>
+        <location filename="../src/mainwindow.cpp" line="852"/>
         <source>&amp;Settings</source>
         <translation>&amp;Configuració</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="815"/>
+        <location filename="../src/mainwindow.cpp" line="855"/>
         <source>&amp;About</source>
         <translation>&amp;Sobre</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="818"/>
+        <location filename="../src/mainwindow.cpp" line="858"/>
         <source>&amp;Quit</source>
         <translation>&amp;Sortir</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="892"/>
+        <location filename="../src/mainwindow.cpp" line="873"/>
+        <source>No internet connection.</source>
+        <translation>Sense connexió a Internet.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="932"/>
         <source>Description: 
 </source>
         <translation>Descripció: 
 </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1491"/>
+        <location filename="../src/mainwindow.cpp" line="1256"/>
+        <source>Offline</source>
+        <translation>Offline</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1257"/>
+        <source>No internet connection available.</source>
+        <translation>Sense connexió a Internet.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1518"/>
         <source>Load plugin...</source>
         <translation>Carrega el plugin...</translation>
     </message>
@@ -269,69 +301,69 @@ La aplicació licitud estarà tancada.</translation>
         <translation>&amp;Mostra imatges</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error while loading plugin.</source>
         <translation>Error en carregar el plugin.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="162"/>
+        <location filename="../src/photobrowser.cpp" line="214"/>
         <source>Past pictures of the day (Wikimedia Commons)</source>
         <translation>Imatges anteriors del dia (Wikimedia Commons)</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="210"/>
+        <location filename="../src/photobrowser.cpp" line="263"/>
         <source>Get more information</source>
         <translation>Obtenir més informació</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="364"/>
+        <location filename="../src/photobrowser.cpp" line="430"/>
         <source>Details</source>
         <translation>Detalls</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="368"/>
+        <location filename="../src/photobrowser.cpp" line="434"/>
         <source>Please select a picture.</source>
         <translation>Seleccioneu una imatge.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="376"/>
+        <location filename="../src/photobrowser.cpp" line="442"/>
         <source>Title: </source>
         <translation>Títol: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="383"/>
+        <location filename="../src/photobrowser.cpp" line="448"/>
         <source>Description: </source>
         <translation>Descripció: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="396"/>
+        <location filename="../src/photobrowser.cpp" line="460"/>
         <source>Picture size:</source>
         <translation>Mida de la imatge:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="406"/>
+        <location filename="../src/photobrowser.cpp" line="470"/>
         <source>Preview:</source>
         <translation>Preestrena:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="444"/>
+        <location filename="../src/photobrowser.cpp" line="508"/>
         <source>Download in progress...</source>
-        <translation type="unfinished">Descàrrega en curs...</translation>
+        <translation>Descàrrega en curs...</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="487"/>
+        <location filename="../src/photobrowser.cpp" line="551"/>
         <source>The entered date must not be in the future.</source>
         <translation>La data introduïda no ha de ser en el futur.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="569"/>
+        <location filename="../src/photobrowser.cpp" line="641"/>
         <source>Working in progress...</source>
-        <translation type="unfinished">Treballant en progrés...</translation>
+        <translation>Treballant en progrés...</translation>
     </message>
 </context>
 <context>
@@ -389,7 +421,7 @@ La aplicació licitud estarà tancada.</translation>
     </message>
     <message>
         <location filename="../src/settingswindow.ui" line="240"/>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>Reset</source>
         <translation>Reinicialitzar</translation>
     </message>
@@ -414,12 +446,12 @@ La aplicació licitud estarà tancada.</translation>
         <translation>Es reiniciarà l&apos;aplicació perquè els canvis entrin en vigor. Vols guardar els canvis?</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="154"/>
+        <location filename="../src/settingswindow.cpp" line="155"/>
         <source>Select directory</source>
         <translation>Seleccionar directori</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
         <translation>Això restablirà tots els paràmetres a la configuració predeterminada. Se suprimiran tots els fons de pantalla existents. Vols continuar?</translation>
     </message>
@@ -427,24 +459,14 @@ La aplicació licitud estarà tancada.</translation>
 <context>
     <name>setWallpaper</name>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="244"/>
-        <source>Error - Failed to set wallpaper.</source>
+        <location filename="../src/setwallpaper.cpp" line="207"/>
+        <source>Error: Failed to set wallpaper on macOS.</source>
         <translation>Error en carregar fons de pantalla.</translation>
     </message>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="275"/>
-        <source>Error: Cannot write wallpaper script to</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="294"/>
-        <source>Warning: Failed to remove temporary wallpaper script</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="299"/>
-        <source>Error: Failed to execute wallpaper script</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/setwallpaper.cpp" line="218"/>
+        <source>Error - Failed to set wallpaper.</source>
+        <translation>Error en carregar fons de pantalla.</translation>
     </message>
 </context>
 </TS>
