@@ -12,52 +12,52 @@
     <message>
         <location filename="../src/about.ui" line="82"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="89"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="133"/>
         <source>tab0</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="178"/>
         <source>label_4</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="191"/>
         <source>label_5</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="204"/>
         <source>label_6</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="230"/>
         <source>tab1</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="257"/>
         <source>TextLabel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="316"/>
         <source>pushButton_3</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="335"/>
         <source>pushButton</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="38"/>
@@ -77,12 +77,12 @@
     <message>
         <location filename="../src/about.cpp" line="54"/>
         <source>Patrice Coni</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="56"/>
         <source>Copyright © 2022 - </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="62"/>
@@ -114,117 +114,149 @@ The application will be closed.</source>
 L&apos;application sera fermée.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
         <source>Reset</source>
-        <translation type="unfinished">Réinitialisation</translation>
+        <translation>Réinitialisation</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
         <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
-        <translation>Le dossier contenant les plugins est introuvable. Voulez-vous définir le dossier manuellement ?</translation>
+        <translation type="vanished">Le dossier contenant les plugins est introuvable. Voulez-vous définir le dossier manuellement ?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="120"/>
         <source>Select directory</source>
-        <translation type="unfinished">Sélectionner un répertoire</translation>
+        <translation type="obsolete">Sélectionner un répertoire</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
+        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
+        <translation>Le dossier contenant les plugins est introuvable. Voulez-vous le définir manuellement&#xa0;?</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="125"/>
+        <source>Select Plugin Folder</source>
+        <translation>Sélectionner le dossier des plugins</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="134"/>
+        <source>No Plugins Found</source>
+        <translation>Aucun plugin trouvé</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="135"/>
+        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
+        <translation>Ce dossier ne contient aucun fichier de plugin (*.so). Veuillez choisir un dossier de plugin valide.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="323"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
+        <location filename="../src/mainwindow.cpp" line="323"/>
         <source>No plugins found.</source>
         <translation>Aucun plugin trouvé.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="315"/>
-        <location filename="../src/mainwindow.cpp" line="766"/>
+        <location filename="../src/mainwindow.cpp" line="329"/>
+        <location filename="../src/mainwindow.cpp" line="806"/>
         <source>done.</source>
         <translation>fait.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="316"/>
-        <location filename="../src/mainwindow.cpp" line="767"/>
+        <location filename="../src/mainwindow.cpp" line="330"/>
+        <location filename="../src/mainwindow.cpp" line="807"/>
         <source>Used plugin: </source>
         <translation>Plugin utilisé: </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error while loading plugin.</source>
         <translation>Erreur lors du chargement du plugin.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="407"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
         <source>An error was detected when starting the application.
 The application will be closed.</source>
         <translation>Une erreur a été détectée lors du démarrage de l’application.
 La demande sera fermée.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
-        <location filename="../src/mainwindow.cpp" line="833"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>No connection to the internet.</source>
         <translation>Pas de connexion à Internet.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>Please check your internet connection.</source>
         <translation>Veuillez vérifier votre connexion Internet.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="756"/>
+        <location filename="../src/mainwindow.cpp" line="796"/>
         <source>&amp;Provider</source>
         <translation>&amp;Fournisseur</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="794"/>
+        <location filename="../src/mainwindow.cpp" line="834"/>
         <source>&amp;About this picture and license</source>
         <translation>&amp;À propos de cette image et licence</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="798"/>
+        <location filename="../src/mainwindow.cpp" line="838"/>
         <source>&amp;About this picture and copyright</source>
         <translation>&amp;À propos de cette image et copyright</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="805"/>
+        <location filename="../src/mainwindow.cpp" line="845"/>
         <source>&amp;Download past pictures</source>
         <translation>&amp;Télécharger les photos passées</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="809"/>
+        <location filename="../src/mainwindow.cpp" line="849"/>
         <source>&amp;Load stored picture</source>
         <translation>&amp;Charger l’image stockée</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="812"/>
+        <location filename="../src/mainwindow.cpp" line="852"/>
         <source>&amp;Settings</source>
         <translation>&amp;Paramètres</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="815"/>
+        <location filename="../src/mainwindow.cpp" line="855"/>
         <source>&amp;About</source>
         <translation>&amp;Environ</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="818"/>
+        <location filename="../src/mainwindow.cpp" line="858"/>
         <source>&amp;Quit</source>
         <translation>&amp;Finir</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="892"/>
+        <location filename="../src/mainwindow.cpp" line="873"/>
+        <source>No internet connection.</source>
+        <translation>Pas de connexion internet.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="932"/>
         <source>Description: 
 </source>
         <translation>Description: 
 </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1491"/>
+        <location filename="../src/mainwindow.cpp" line="1256"/>
+        <source>Offline</source>
+        <translation>Offline</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1257"/>
+        <source>No internet connection available.</source>
+        <translation>Pas de connexion internet.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1518"/>
         <source>Load plugin...</source>
         <translation>Charger le plugin...</translation>
     </message>
@@ -269,69 +301,69 @@ La demande sera fermée.</translation>
         <translation>&amp;Afficher les photos</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error while loading plugin.</source>
         <translation>Erreur lors du chargement du plugin.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="162"/>
+        <location filename="../src/photobrowser.cpp" line="214"/>
         <source>Past pictures of the day (Wikimedia Commons)</source>
         <translation>Photos passées de la journée (Wikimedia Commons)</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="210"/>
+        <location filename="../src/photobrowser.cpp" line="263"/>
         <source>Get more information</source>
         <translation>Obtenir plus d’informations</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="364"/>
+        <location filename="../src/photobrowser.cpp" line="430"/>
         <source>Details</source>
         <translation>Détails</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="368"/>
+        <location filename="../src/photobrowser.cpp" line="434"/>
         <source>Please select a picture.</source>
         <translation>Veuillez sélectionner une image.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="376"/>
+        <location filename="../src/photobrowser.cpp" line="442"/>
         <source>Title: </source>
         <translation>Titre: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="383"/>
+        <location filename="../src/photobrowser.cpp" line="448"/>
         <source>Description: </source>
         <translation>Description: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="396"/>
+        <location filename="../src/photobrowser.cpp" line="460"/>
         <source>Picture size:</source>
         <translation>Taille de l’image:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="406"/>
+        <location filename="../src/photobrowser.cpp" line="470"/>
         <source>Preview:</source>
         <translation>Aperçu:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="444"/>
+        <location filename="../src/photobrowser.cpp" line="508"/>
         <source>Download in progress...</source>
-        <translation type="unfinished">Téléchargement en cours...</translation>
+        <translation>Téléchargement en cours...</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="487"/>
+        <location filename="../src/photobrowser.cpp" line="551"/>
         <source>The entered date must not be in the future.</source>
         <translation>La date saisie ne doit pas être dans le futur.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="569"/>
+        <location filename="../src/photobrowser.cpp" line="641"/>
         <source>Working in progress...</source>
-        <translation type="unfinished">Travaux en cours...</translation>
+        <translation>Travaux en cours...</translation>
     </message>
 </context>
 <context>
@@ -389,7 +421,7 @@ La demande sera fermée.</translation>
     </message>
     <message>
         <location filename="../src/settingswindow.ui" line="240"/>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>Reset</source>
         <translation>Réinitialisation</translation>
     </message>
@@ -414,12 +446,12 @@ La demande sera fermée.</translation>
         <translation>L’application sera redémarrée pour que les modifications prennent effet. Voulez-vous enregistrer les modifications ?</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="154"/>
+        <location filename="../src/settingswindow.cpp" line="155"/>
         <source>Select directory</source>
         <translation>Sélectionner un répertoire</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
         <translation>Cela réinitialisera tous les paramètres aux paramètres par défaut. Tous les fonds d’écran existants seront supprimés. Voulez-vous continuer?</translation>
     </message>
@@ -427,24 +459,14 @@ La demande sera fermée.</translation>
 <context>
     <name>setWallpaper</name>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="244"/>
-        <source>Error - Failed to set wallpaper.</source>
+        <location filename="../src/setwallpaper.cpp" line="207"/>
+        <source>Error: Failed to set wallpaper on macOS.</source>
         <translation>Erreur - Impossible de définir le papier peint.</translation>
     </message>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="275"/>
-        <source>Error: Cannot write wallpaper script to</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="294"/>
-        <source>Warning: Failed to remove temporary wallpaper script</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="299"/>
-        <source>Error: Failed to execute wallpaper script</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/setwallpaper.cpp" line="218"/>
+        <source>Error - Failed to set wallpaper.</source>
+        <translation>Erreur - Impossible de définir le papier peint.</translation>
     </message>
 </context>
 </TS>
