@@ -12,52 +12,52 @@
     <message>
         <location filename="../src/about.ui" line="82"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="89"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="133"/>
         <source>tab0</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="178"/>
         <source>label_4</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="191"/>
         <source>label_5</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="204"/>
         <source>label_6</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="230"/>
         <source>tab1</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="257"/>
         <source>TextLabel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="316"/>
         <source>pushButton_3</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.ui" line="335"/>
         <source>pushButton</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../src/about.cpp" line="38"/>
@@ -114,117 +114,149 @@ The application will be closed.</source>
 Заявка буде закрита.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
         <source>Reset</source>
-        <translation type="unfinished">Скинути</translation>
+        <translation>Скинути</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="114"/>
         <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
-        <translation>Папка, яка містить плагіни, не була знайдена. Хочете встановити папку вручну?</translation>
+        <translation type="vanished">Папка, яка містить плагіни, не була знайдена. Хочете встановити папку вручну?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="120"/>
         <source>Select directory</source>
-        <translation type="unfinished">Виберіть каталог</translation>
+        <translation type="obsolete">Виберіть каталог</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="119"/>
+        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
+        <translation>Папку з плагінами не знайдено. Бажаєте встановити папку вручну?</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="125"/>
+        <source>Select Plugin Folder</source>
+        <translation>Виберіть папку плагіна</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="134"/>
+        <source>No Plugins Found</source>
+        <translation>Плагіни не знайдено</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="135"/>
+        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
+        <translation>Папка не містить жодних файлів плагіна (*.so). Будь ласка, виберіть дійсну папку плагіна.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="323"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="309"/>
+        <location filename="../src/mainwindow.cpp" line="323"/>
         <source>No plugins found.</source>
         <translation>Плагінів не знайдено.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="315"/>
-        <location filename="../src/mainwindow.cpp" line="766"/>
+        <location filename="../src/mainwindow.cpp" line="329"/>
+        <location filename="../src/mainwindow.cpp" line="806"/>
         <source>done.</source>
         <translation>зроблено.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="316"/>
-        <location filename="../src/mainwindow.cpp" line="767"/>
+        <location filename="../src/mainwindow.cpp" line="330"/>
+        <location filename="../src/mainwindow.cpp" line="807"/>
         <source>Used plugin: </source>
         <translation>Використовуваний плагін: </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="320"/>
-        <location filename="../src/mainwindow.cpp" line="771"/>
+        <location filename="../src/mainwindow.cpp" line="334"/>
+        <location filename="../src/mainwindow.cpp" line="811"/>
         <source>Error while loading plugin.</source>
         <translation>Помилка під час завантаження плагіна.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="407"/>
+        <location filename="../src/mainwindow.cpp" line="424"/>
         <source>An error was detected when starting the application.
 The application will be closed.</source>
         <translation>An error was detected when starting the program.
 The application will be closed.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
-        <location filename="../src/mainwindow.cpp" line="833"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>No connection to the internet.</source>
         <translation>Немає підключення до інтернету.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="476"/>
+        <location filename="../src/mainwindow.cpp" line="493"/>
         <source>Please check your internet connection.</source>
         <translation>Будь ласка, перевірте підключення до Інтернету.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="756"/>
+        <location filename="../src/mainwindow.cpp" line="796"/>
         <source>&amp;Provider</source>
         <translation>&amp;Постачальника</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="794"/>
+        <location filename="../src/mainwindow.cpp" line="834"/>
         <source>&amp;About this picture and license</source>
         <translation>&amp;Про цю картинку і ліцензію</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="798"/>
+        <location filename="../src/mainwindow.cpp" line="838"/>
         <source>&amp;About this picture and copyright</source>
         <translation>&amp;Про цю картину і авторські права</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="805"/>
+        <location filename="../src/mainwindow.cpp" line="845"/>
         <source>&amp;Download past pictures</source>
         <translation>&amp;Завантаження минулих зображень</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="809"/>
+        <location filename="../src/mainwindow.cpp" line="849"/>
         <source>&amp;Load stored picture</source>
         <translation>&amp;Відкриття збереженого зображення</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="812"/>
+        <location filename="../src/mainwindow.cpp" line="852"/>
         <source>&amp;Settings</source>
         <translation>&amp;Параметри</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="815"/>
+        <location filename="../src/mainwindow.cpp" line="855"/>
         <source>&amp;About</source>
         <translation>&amp;Про</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="818"/>
+        <location filename="../src/mainwindow.cpp" line="858"/>
         <source>&amp;Quit</source>
         <translation>&amp;Кинути</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="892"/>
+        <location filename="../src/mainwindow.cpp" line="873"/>
+        <source>No internet connection.</source>
+        <translation>Немає підключення до інтернету.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="932"/>
         <source>Description: 
 </source>
         <translation>Опис: 
 </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1491"/>
+        <location filename="../src/mainwindow.cpp" line="1256"/>
+        <source>Offline</source>
+        <translation>Офлайн</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1257"/>
+        <source>No internet connection available.</source>
+        <translation>Немає підключення до інтернету.</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1518"/>
         <source>Load plugin...</source>
         <translation>Запуск плагіна...</translation>
     </message>
@@ -269,69 +301,69 @@ The application will be closed.</translation>
         <translation>&amp;Показати картинки</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="157"/>
+        <location filename="../src/photobrowser.cpp" line="209"/>
         <source>Error while loading plugin.</source>
         <translation>Помилка під час запуску плагіна.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="162"/>
+        <location filename="../src/photobrowser.cpp" line="214"/>
         <source>Past pictures of the day (Wikimedia Commons)</source>
         <translation>Минулі фотографії дня (Вікісховище)</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="210"/>
+        <location filename="../src/photobrowser.cpp" line="263"/>
         <source>Get more information</source>
         <translation>Отримати більше інформації</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="364"/>
+        <location filename="../src/photobrowser.cpp" line="430"/>
         <source>Details</source>
         <translation>Деталі</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="368"/>
+        <location filename="../src/photobrowser.cpp" line="434"/>
         <source>Please select a picture.</source>
         <translation>Будь ласка, виберіть зображення.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="376"/>
+        <location filename="../src/photobrowser.cpp" line="442"/>
         <source>Title: </source>
         <translation>Назва: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="383"/>
+        <location filename="../src/photobrowser.cpp" line="448"/>
         <source>Description: </source>
         <translation>Опис: </translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="396"/>
+        <location filename="../src/photobrowser.cpp" line="460"/>
         <source>Picture size:</source>
         <translation>Розмір картинки:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="406"/>
+        <location filename="../src/photobrowser.cpp" line="470"/>
         <source>Preview:</source>
         <translation>Попередній перегляд:</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="444"/>
+        <location filename="../src/photobrowser.cpp" line="508"/>
         <source>Download in progress...</source>
-        <translation type="unfinished">Завантаження триває...</translation>
+        <translation>Завантаження триває...</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="487"/>
+        <location filename="../src/photobrowser.cpp" line="551"/>
         <source>The entered date must not be in the future.</source>
         <translation>Введеної дати не повинно бути в майбутньому.</translation>
     </message>
     <message>
-        <location filename="../src/photobrowser.cpp" line="569"/>
+        <location filename="../src/photobrowser.cpp" line="641"/>
         <source>Working in progress...</source>
-        <translation type="unfinished">У процесі...</translation>
+        <translation>У процесі...</translation>
     </message>
 </context>
 <context>
@@ -389,7 +421,7 @@ The application will be closed.</translation>
     </message>
     <message>
         <location filename="../src/settingswindow.ui" line="240"/>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>Reset</source>
         <translation>Скинути</translation>
     </message>
@@ -414,12 +446,12 @@ The application will be closed.</translation>
         <translation>Додаток буде перезапущено, щоб зміни вступили в силу. Хочете зберегти зміни?</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="154"/>
+        <location filename="../src/settingswindow.cpp" line="155"/>
         <source>Select directory</source>
         <translation>Виберіть каталог</translation>
     </message>
     <message>
-        <location filename="../src/settingswindow.cpp" line="175"/>
+        <location filename="../src/settingswindow.cpp" line="176"/>
         <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
         <translation>Це призведе до скидання всіх налаштувань до налаштувань за замовчуванням. Всі існуючі шпалери будуть видалені. Хочете продовжити?</translation>
     </message>
@@ -427,24 +459,14 @@ The application will be closed.</translation>
 <context>
     <name>setWallpaper</name>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="244"/>
-        <source>Error - Failed to set wallpaper.</source>
+        <location filename="../src/setwallpaper.cpp" line="207"/>
+        <source>Error: Failed to set wallpaper on macOS.</source>
         <translation>Не вдалося встановити шпалери.</translation>
     </message>
     <message>
-        <location filename="../src/setwallpaper.cpp" line="275"/>
-        <source>Error: Cannot write wallpaper script to</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="294"/>
-        <source>Warning: Failed to remove temporary wallpaper script</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/setwallpaper.cpp" line="299"/>
-        <source>Error: Failed to execute wallpaper script</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/setwallpaper.cpp" line="218"/>
+        <source>Error - Failed to set wallpaper.</source>
+        <translation>Не вдалося встановити шпалери.</translation>
     </message>
 </context>
 </TS>
