@@ -1,5 +1,5 @@
 /**
- * "UltimateDailyWallpaper" Copyright (C) 2025 Patrice Coni
+ * "UltimateDailyWallpaper" Copyright (C) 2026 Patrice Coni
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ MainWindow::MainWindow(QWidget *parent)
     QDir _settDir(_AppFileDir);
     if(!_settDir.exists())
     {
-        if(check_internet_connection()==true)
+        if(hasInternet())
         {
             _settDir.mkpath(_AppFileDir);
         }
@@ -292,11 +292,6 @@ MainWindow::MainWindow(QWidget *parent)
             _applang="pt";
             change_applang(_applang);
         }
-        else if (_locale.contains("ko"))
-        {
-            _applang="ko";
-            change_applang(_applang);
-        }
         else if (_locale.contains("ca"))
         {
             _applang="ca";
@@ -479,7 +474,7 @@ MainWindow::MainWindow(QWidget *parent)
             load_wallpaper();
         } else
         {
-            if(check_internet_connection()==true)
+            if(hasInternet())
             {
                 update_all();
             } else
@@ -493,7 +488,7 @@ MainWindow::MainWindow(QWidget *parent)
         no_autochange();
     }
 
-    if(check_internet_connection()==false)
+    if(!hasInternet())
     {
         _display_tooltip(tr("No connection to the internet."), tr("Please check your internet connection."));
     }
@@ -658,41 +653,9 @@ void MainWindow::load_settings()
     settings.endGroup();
 }
 
-bool MainWindow::check_internet_connection()
-{
-    QNetworkReply *reply;
-    QNetworkAccessManager dl_manager;
-
-    bool _error=false;
-    QString _check_url = "https://www.wikimedia.org";
-    QEventLoop loop;
-    QObject::connect(&dl_manager,&QNetworkAccessManager::finished,&loop,&QEventLoop::quit);
-    reply = dl_manager.get(QNetworkRequest(_check_url));
-    loop.exec();
-
-    if (!reply->bytesAvailable())
-    {
-        _error=true;
-    }
-    else
-    {
-        _error=false;
-    }
-
-    reply->close();
-    loop.exit();
-
-    if(_error==true)
-    {
-        return false;
-    }
-
-    return true;
-}
-
 void MainWindow::request_dl_wallpaper()
 {
-    if(check_internet_connection()==true)
+    if(hasInternet())
     {
         basicinterface->get_picture(false, _picturedir, _applang, 0, 0, 0);
         if(regular_request==false)
@@ -713,6 +676,22 @@ void MainWindow::request_dl_wallpaper()
         if(startseq==true)
         {
             startseq=false;
+
+            // Retry every 5 seconds until the internet is available (max. 5 minutes in total)
+            static int retryCount = 0;
+            const int maxRetries = 60;  // 60 retries = max. 5 minutes (300 seconds)
+
+            if (retryCount < maxRetries)
+            {
+                retryCount++;
+                qDebug() << "[NET] Internet unavailable, retrying... Attempt:" << retryCount;
+                QTimer::singleShot(5000, this, &MainWindow::request_dl_wallpaper);  // Retry after 5 seconds
+            }
+            else
+            {
+                qDebug() << "[NET] Maximum retry limit reached. Download failed.";
+                retryCount = 0;  // Reset retry count for the next session
+            }
         }
     }
     else
@@ -882,7 +861,7 @@ void MainWindow::create_Actions()
 
 void MainWindow::wikimedia_commons_more_pictures()
 {
-    if(check_internet_connection()==true)
+    if (hasInternet())
     {
         show_photobrowser(1);
     }
@@ -891,7 +870,7 @@ void MainWindow::wikimedia_commons_more_pictures()
         QApplication::setQuitOnLastWindowClosed(false);
         QMessageBox MsgError;
         MsgError.setIcon(QMessageBox::Warning);
-        MsgError.setText(tr("No connection to the internet."));
+        MsgError.setText(tr("No internet connection."));
         MsgError.exec();
     }
 }
@@ -1271,19 +1250,27 @@ void MainWindow::update_menu()
 
 void MainWindow::update_all()
 {
-    regular_request=true;
+    if (!hasInternet())
+    {
+        _display_tooltip(
+            tr("Offline"),
+            tr("No internet connection available.")
+        );
+        return;
+    }
+
+    regular_request = true;
     request_dl_wallpaper();
     get_record("", "", _selected_provider, true);
     update_menu();
-    if(_autochange==2)
-    {
+
+    if (_autochange == 2)
         load_wallpaper();
-    }
+
     _display_tooltip(_record_out.at(1), _record_out.at(0));
-    if((check_internet_connection()==true) && (same_date()==false))
-    {
+
+    if (!same_date())
         change_date();
-    }
 }
 
 void MainWindow::show_photobrowser(int mode)
@@ -1589,3 +1576,55 @@ bool MainWindow::same_date()
         return false;
     }
 }
+
+bool MainWindow::hasInternet()
+{
+    QDateTime now = QDateTime::currentDateTime();
+
+    if (!_lastInternetCheck.isValid() ||
+        _lastInternetCheck.secsTo(now) >= _internetCheckIntervalSec)
+    {
+        _isOnline = check_internet_connection();
+        _lastInternetCheck = now;
+
+        qDebug() << "[NET] Internet rechecked:" << _isOnline;
+    }
+    else
+    {
+        qDebug() << "[NET] Cached internet state used:" << _isOnline;
+    }
+
+    return _isOnline;
+}
+
+bool MainWindow::check_internet_connection()
+{
+    QNetworkReply *reply;
+    QNetworkAccessManager dl_manager;
+
+    bool _error=false;
+    QString _check_url = "https://www.wikimedia.org";
+    QEventLoop loop;
+    QObject::connect(&dl_manager,&QNetworkAccessManager::finished,&loop,&QEventLoop::quit);
+    reply = dl_manager.get(QNetworkRequest(_check_url));
+    loop.exec();
+
+    if (!reply->bytesAvailable())
+    {
+        _error=true;
+    }
+    else
+    {
+        _error=false;
+    }
+
+    reply->close();
+    loop.exit();
+
+    if(_error==true)
+    {
+        return false;
+    }
+
+    return true;
+}
