@@ -1,5 +1,5 @@
 /**
- * "UltimateDailyWallpaper" Copyright (C) 2025 Patrice Coni
+ * "UltimateDailyWallpaper" Copyright (C) 2026 Patrice Coni
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -346,7 +346,6 @@ void PhotoBrowser::_get_values()
 {
     QString connectionName = "PhotoBrowserConnection";
 
-    // Scope sorgt dafür, dass db und query zerstört werden, bevor removeDatabase aufgerufen wird
     {
         QSqlDatabase udw_db;
 
@@ -410,9 +409,8 @@ void PhotoBrowser::_get_values()
         }
 
         udw_query.finish();
-    } // udw_query und udw_db gehen hier aus dem Scope -> Verbindung ist frei
+    }
 
-    // Verbindung jetzt sicher entfernen, falls noch vorhanden
     if(QSqlDatabase::contains(connectionName)) {
         QSqlDatabase::removeDatabase(connectionName);
     }
@@ -611,9 +609,8 @@ bool PhotoBrowser::create_temp_database()
             udw_temp_query.finish();
             udw_temp_query.clear();
         }
-    } // udw_temp_db & udw_temp_query verlassen den Scope
+    }
 
-    // Verbindung entfernen
     if(QSqlDatabase::contains(connectionName))
         QSqlDatabase::removeDatabase(connectionName);
 
@@ -687,7 +684,6 @@ void PhotoBrowser::download_and_set()
 
 bool PhotoBrowser::select_single_value(QString desired_column, QString db_filepath)
 {
-    // Only allow valid columns
     static const QStringList allowedColumns = {
         "filename", "description", "copyright", "title",
         "browser_url", "size_width", "size_height", "potd_date"
@@ -700,8 +696,7 @@ bool PhotoBrowser::select_single_value(QString desired_column, QString db_filepa
 
     QString connectionName = "PhotoBrowserSelectConnection";
 
-    // Scope sorgt dafür, dass db und query zerstört werden, bevor removeDatabase aufgerufen wird
-    bool result = false; // Rückgabewert
+    bool result = false;
 
     {
         QSqlDatabase udw_db;
@@ -734,9 +729,8 @@ bool PhotoBrowser::select_single_value(QString desired_column, QString db_filepa
         }
 
         udw_query.finish();
-    } // udw_query und udw_db gehen hier aus dem Scope -> Verbindung ist frei
+    }
 
-    // Verbindung jetzt sicher entfernen, falls noch vorhanden
     if(QSqlDatabase::contains(connectionName)) {
         QSqlDatabase::removeDatabase(connectionName);
     }
@@ -852,9 +846,8 @@ void PhotoBrowser::_add_record(QString _description,
 
         udw_query.finish();
         udw_query.clear();
-    } // udw_query & udw_db verlassen den Scope -> Verbindung frei
+    }
 
-    // Verbindung entfernen
     if(QSqlDatabase::contains(connectionName))
     {
         QSqlDatabase::removeDatabase(connectionName);
